@@ -97,7 +97,8 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 	
 	centralWidget = new QWidget(this);
 
-	centralWidget->setContextMenuPolicy(Qt::CustomContextMenu);
+	//setContextMenuPolicy(Qt::DefaultContextMenu);
+	setContextMenuPolicy(Qt::CustomContextMenu);
 
 	vboxlayout = new QVBoxLayout ();
 	vboxlayout->setSpacing(0);
@@ -162,12 +163,12 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 
 	componentLayout = new QGridLayout ();
 
-	setContextMenuPolicy(Qt::CustomContextMenu);
-	//QObject::connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardMenu(const QPoint&)));
+	//setContextMenuPolicy(Qt::CustomContextMenu);
+	QObject::connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardMenu(const QPoint&)));
 
 	if (edit || target->getPicture() != NULL) {
 		imageLabel = new QLabel(this);
-		imageLabel->setContextMenuPolicy(Qt::CustomContextMenu);
+		//imageLabel->setContextMenuPolicy(Qt::CustomContextMenu);
 		imageLabel->setBackgroundRole(QPalette::NoRole);
 		imageLabel->setContentsMargins(5, 2, 0, 2);
 		if (edit) {
@@ -176,7 +177,8 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 			imageLabel->setScaledContents(true);
 		}
 		else {
-			//imageLabel->setMaximumSize(MAX_WIDTH, MAX_HEIGH);
+			imageLabel->setMaximumSize(MAX_WIDTH, MAX_HEIGH);
+			imageLabel->setMinimumSize(MAX_WIDTH, MAX_HEIGH);
 			imageLabel->setScaledContents(true);
 		}
 		if (currentImage == NULL) {
@@ -187,7 +189,7 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 			imageLabel->setPixmap(QPixmap::fromImage (*currentImage));
 		}
 		
-		QObject::connect(imageLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardFaceMenu(const QPoint&)));
+		//QObject::connect(imageLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardFaceMenu(const QPoint&)));
 		if (edit) {
 			componentLayout->addWidget(imageLabel, 3, 1, 2, 3);
 		}
@@ -200,7 +202,7 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 
 	if (edit || target->getPictureBack() != NULL) {
 		imageBackLabel = new QLabel(this);
-		imageBackLabel->setContextMenuPolicy(Qt::CustomContextMenu);
+		//imageBackLabel->setContextMenuPolicy(Qt::CustomContextMenu);
 		imageBackLabel->setBackgroundRole(QPalette::NoRole);
 		//imageBackLabel->setFocusPolicy(Qt::StrongFocus);
 		imageBackLabel->setContentsMargins(5, 2, 0, 2);
@@ -211,6 +213,8 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 		}
 		else {
 			//imageBackLabel->setMaximumSize(MAX_WIDTH, MAX_HEIGH);
+			imageBackLabel->setMaximumSize(MAX_WIDTH, MAX_HEIGH);
+			imageBackLabel->setMinimumSize(MAX_WIDTH, MAX_HEIGH);
 			imageBackLabel->setScaledContents(true);
 		}
 		if (currentImageBack == NULL) {
@@ -221,7 +225,7 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 			imageBackLabel->setPixmap(QPixmap::fromImage (*currentImageBack));
 		}
 
-		QObject::connect(imageBackLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardBackMenu(const QPoint&)));
+		//QObject::connect(imageBackLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardBackMenu(const QPoint&)));
 		if (edit) {
 			componentLayout->addWidget(imageBackLabel, 3, 4, 2, 3);
 		}
@@ -592,7 +596,7 @@ void DetailWindow::cardMenu(const QPoint & _p) {
 			menu.addAction("Delete", this, SLOT(deleteCardFace()));
 		}
 		else {
-			menu.addAction("Export", this, SLOT(exportCardFace()));
+			menu.addAction("Export Face", this, SLOT(exportCardFace()));
 		}
 		menu.exec(_p);
 	}
@@ -605,7 +609,7 @@ void DetailWindow::cardMenu(const QPoint & _p) {
 			menu.addAction("Delete", this, SLOT(deleteCardBack()));
 		}
 		else {
-			menu.addAction("Export", this, SLOT(exportCardBack()));
+			menu.addAction("Export Back", this, SLOT(exportCardBack()));
 		}
 		menu.exec(_p);
 	}
